import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import QRCode 1.0

Page
{
	id: decoder_page
	
	property alias decodedText: decoded_text_box.text
	property alias imgSource: img_to_decode.source
	
	property int p_id
	p_id:2
	
	
	orientationLock: PageOrientation.LockPortrait
	
	Header
	{
		id: h_decoder
		statusText: qsTr("Simple Decoder")
	}
	
	function openFile(file)
	{
		var component = Qt.createComponent(file)
		
		if (component.status == Component.Ready)
			pageStack.push(component);
		else
			console.log("Error loading component:", component.errorString());
	}
	
	Image
	{
		id:img_to_decode
		width: parent.width*3/5
		height: width
		cache: false
		source:"select_file_to_decode.png"
		anchors.margins: 16
		anchors.top: h_decoder.bottom
		anchors.left: parent.left
		anchors.right: parent.right
		fillMode: Image.PreserveAspectFit
		MouseArea
		{
			anchors.fill:parent
			onClicked:
			{
				//openFile("FileBox.qml");
				openFile("Gallery.qml");
			}
		}
	}
	
	Label
	{
		id: type_label
		width:parent.width
		anchors.top:img_to_decode.bottom
		text:qsTr("Type : ")
	}
	
	Label
	{
		id: d_label
		width: parent.width
		anchors.top:type_label.bottom
		text: qsTr("Decoded Text : ")
	}
	
	Item
	{
		id: x_item
		anchors.top: d_label.bottom
		anchors.left: parent.left
		anchors.right: parent.right
		anchors.bottom: parent.bottom
		Flickable
		{
			id:f_item
			anchors.fill: parent
			contentWidth: parent.width
			contentHeight: parent.height
			clip: true
			flickableDirection: Flickable.VerticalFlick
			anchors
			{
				top: parent.top;
				topMargin: 15;
				left: parent.left;
				leftMargin: 15;
				right: parent.right;
				rightMargin: 15
			}
			Text
			{
				id:decoded_text_box
				width:parent.width
				anchors.margins: 20
				anchors.top: parent.top
				anchors.bottom: parent.bottom
				anchors.left: parent.left
				anchors.right: parent.right
				font.pointSize: 18
				wrapMode: Text.WrapAnywhere
				//clip: true
				text: qsTr("Press to select image")
				MouseArea
				{
					anchors.fill:parent
					onClicked:
					{
						menu_text.open();
					}
				}
			}
		}
	}
	
	Item
	{
		id: waitDialogue
		visible: false
		anchors.fill: parent;
		z:100
		Rectangle
		{
			id:shaderLayer
			anchors.bottom: parent.bottom
			width: parent.width
			height: parent.height
			color: "darkgray"
			opacity: 0.5
			MouseArea
			{
				anchors.fill: parent
			}
		}
		Item
		{
			anchors.horizontalCenter: parent.horizontalCenter
			anchors.verticalCenter: parent.verticalCenter
			height: 100
			width: 100
			BusyIndicator {
				id: busyindicator
				style: BusyIndicatorStyle { size: "large" }
				running:  true
			}
		}
	}
	
	function process(m)
	{
		if(m)
		{
			waitDialogue.visible = true
		}else
		{
			waitDialogue.visible = false
		}
	}
	
	function setType(b_type)
	{
		type_label.text= qsTr("Type : ")+b_type;
	}
	
	ToolBarLayout
	{
		id: settingTools
		visible: false
		ToolIcon
		{
			iconId: "toolbar-back";
			onClicked:
			{
				pageStack.pop();
			}
		}
		ToolIcon
		{
			iconId: "toolbar-camera";
			onClicked:
			{
				openFile("CamPage.qml");
			}
		}
	}
	tools: settingTools

	Clipboard
	{
		id:clipboard
	}

	Menu
	{
		id: menu_text
		visualParent: pageStack
	
		MenuLayout
		{
			MenuItem
			{
				text: qsTr("Search");
				onClicked:
				{
					Qt.openUrlExternally("http://m.google.com/m?q="+decoded_text_box.text);
				}
			}
			MenuItem
			{
				text: qsTr("Copy to clip board");
				onClicked:
				{
					clipboard.setText(decoded_text_box.text);
				}
			}
		}
	}
}
