import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import Qt.labs.folderlistmodel 1.0

Page
{
	id: selector
	
	property int p_id
	p_id:4
	
	orientationLock: PageOrientation.LockPortrait
	
	function stripFilePath(path)
	{
		var filePath = new String(path)
		return filePath.replace("/home/user/MyDocs", "")
	}
	
	function stripFilePrefix(path)
	{
		var filePath = new String(path)
		return filePath.replace("file://", "")
	}
	
	function stripSuffix(path)
	{
		var filePath = new String(path)
		return filePath.substring(0, filePath.lastIndexOf("/"))
	}
	
	function setCurrentFolder(folder)
	{
		folderModel.folder = folder
		h_selector.statusText = stripFilePrefix(folder)
	}
	
	
	
	Header
	{
		id: h_selector
		//statusText: "Simple Decoder"
		statusText: stripFilePrefix(folderModel.folder)
	}
	
	ListView
	{
		id: list
		clip: true
		anchors.top: h_selector.bottom
		anchors.bottom: parent.bottom
		width: parent.width
		model: folderModel
		spacing: 2
		section.property: "path"
		delegate: fileDelegate
		highlight: Rectangle { color: "lightsteelblue"; radius: 5 }
	}
	
	FolderListModel
	{
		id: folderModel
		nameFilters: ["*.png","*.jpg","*.jpeg","*.PNG","*.JPG","*.JPEG"]
		sortField: "Type"
		showDirs : true
		folder:  "/home/user/MyDocs/QRs"
	}
	
	Component
	{
		id: fileDelegate
		Item
		{
			id: container
			height: 64
			width: parent.width
			
			Rectangle {
				id: background
				x: -1; y: 0; width: parent.width - x*2; height: parent.height - y*2
				border.color: "gray"
				radius: 0
				Label
				{
					id: label_fileName
					anchors.fill: parent
					text: fileName
					font.pixelSize: 25
				}
			}
			
			MouseArea
			{
				hoverEnabled : true
				anchors.fill:parent
				
				onReleased:
				{
					if(folderModel.isFolder(index))
					{
						folderModel.folder=filePath
						setCurrentFolder(filePath)
					}else
					{
						//decoder_page.img_to_decode.source = filePath
						qr_engine.slot_simpleDecode(filePath)
						pageStack.find(function(page)
							{
								return page.p_id == "2";
							}
						).imgSource = filePath;
						pageStack.find(function(page)
							{
								return page.p_id == "2";
							}
						).process(true)
						pageStack.pop();
					}
				}
			}
		}
	}
	
	SectionScroller
	{
		listView: list
	}
	
	ScrollDecorator
	{
		flickableItem: list
	}
	
	ToolBarLayout
	{
		id: settingTools
		visible: false
		ToolIcon
		{
			iconId: "toolbar-back";
			onClicked:
			{
				pageStack.pop();
			}
		}
		ToolIcon {
			iconId: "toolbar-up"
			onClicked: {
				console.log("Up button clicked, current folder:", folderModel.folder)
				if (stripFilePrefix(folderModel.folder) !== "/") {
					setCurrentFolder(stripFilePrefix(stripSuffix(folderModel.folder)))
					console.log("changed folder:", folderModel.folder)
				}
			}
		}
		ToolIcon
		{
			iconId: "icon-m-toolbar-gallery"
			onClicked:
			{
				//var myPage = Qt.createComponent("Gallery.qml")
				var myPage = Qt.resolvedUrl("Gallery.qml");
				/*myPage.parent = pageStack.find(function(page)
					{
						return page.p_id == "2";
					});*/
				pageStack.replace(myPage)
			}
		}
	}
	tools: settingTools
}
