import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page
{
	id:mainPage
	
	property alias source: result_img.source
	property alias infoBanner: banner
	
	orientationLock: PageOrientation.LockPortrait
	
	Header
	{
		id: header;
	}

	function setStatusText()
	{
        	if(EvernoteSession.isSyncInProgress())
		{
			return;
		}
		header.statusText =  qsTr("QReader")
	}
	
	function openFile(file)
	{
		var component = Qt.createComponent(file)
		
		if (component.status == Component.Ready)
			pageStack.push(component);
		else
			console.log("Error loading component:", component.errorString());
	}
	

	InfoBanner
	{
		id: banner
		x: 0
		y: 0
	 	z: 10
		text: qsTr("Saved as xxx.png !");
	}

	TextField
	{
		id:origText
		placeholderText: qsTr("Your Text Here");
		width:parent.width * 8/10
		anchors
		{
			top:header.bottom
			topMargin: 20
		}
		Image
		{
			id: clearButton
			anchors.right: parent.right
			anchors.verticalCenter: parent.verticalCenter
			source: "image://theme/icon-m-input-clear"
			MouseArea
			{
				anchors.fill: parent
				onClicked:
				{
					inputContext.reset();
					origText.text = "";
				}
			}
		}
	}
	
	Button
	{
		id:btnGo
		text:qsTr("Go")
		width: parent.width *2/10
		height: origText.height
		anchors
		{
			top:header.bottom
			left:origText.right
			topMargin: 20
		}
		onClicked:
		{
			qr_engine.slot_generateTemp(origText.text);
		}
	}


	Image
	{
		id:result_img
		source:"b_img.png"
		width:parent.width*4/5
		height: width
		cache: false
		anchors
		{
			top:origText.bottom
			topMargin: 50
			horizontalCenter: parent.horizontalCenter
		}
	}

	Button
	{
		id:btn_save
		text:qsTr("Save")
		width:parent.width*1/4
		anchors
		{
			top:result_img.bottom
			topMargin: 50
			right: parent.right
		}
		onClicked: qr_engine.slot_generateSaved(origText.text);
	}

	QueryDialog
	{
		id:aboutDialog
		icon: "/opt/qr/icons/qr_enc_128x128.png"
		titleText:qsTr("About QRCoDe")
		message:qsTr("QR Encoder by\nlovewilliam<lovewilliam@gmail.com>\nhttp://www.bigstarstar.tk\n;-)")
		acceptButtonText: qsTr("OK")
	}

	QueryDialog
	{
		id:edit_preDialog
		titleText:qsTr("Editor")
		message:qsTr("Encode something\nthen press edit button to edit ;-)")
		acceptButtonText: qsTr("OK")
	}
	
	ToolBarLayout
	{
	        id: commonTools
        	visible: true
        	
        	ToolIcon
        	{
			id: tool_btn_edit
			iconId: "icon-m-toolbar-edit"
			anchors.left:parent.left
			onClicked:
			{
				//TODO! open edit here
				if(qr_engine.isEncoded())
				{
					//Open edit here
					openFile("Edit.qml");
				}else
				{
					edit_preDialog.open();
				}
			}
		}
        	
	        ToolIcon
		{
        		platformIconId: "toolbar-view-menu"
        		anchors.right: (parent === undefined) ? undefined : parent.right
			onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close();
	        }
	}
	Menu
	{
        	id: myMenu
        	visualParent: pageStack
	        MenuLayout
		{
			MenuItem
			{
				id: miDecoder
				text: qsTr("Simple Decoder")
				onClicked:
				{
					mainPage.openFile("Decode.qml");
				}
			}
			MenuItem
			{
				id: miAbout
				text: qsTr("About")
				onClicked:
				{
					aboutDialog.open();
				}
			}
			MenuItem
			{
        			id: miExit
		                text: qsTr("Exit")
				onClicked:
				{
					Qt.quit()
				}
 			}
		}
	}
	tools: commonTools

}



